.. _zephyr_tutorial:

MicroPython tutorial for the Zephyr port
========================================

This tutorial is intended to get you started with the Zephyr port.

.. toctree::
   :maxdepth: 1
   :numbered:

   intro.rst
   repl.rst
   storage.rst
   pins.rst

